@@ -5,12 +5,15 @@
     ~~~~~~~~~~~~~~
     Setup webpy app with additional waltz;
     Sessions and authentication, templates, etc.
+
+    :copyright: (c) 2012 by Mek
+    :license: BSD, see LICENSE for more details.
 """
 
 import os
+from functools import partial
 import web
 from web import wsgiserver
-from functools import partial
 from reloader import PeriodicReloader
 _https = wsgiserver.CherryPyWSGIServer
 
@@ -69,12 +72,21 @@ def dancefloor(urls, fvars, sessions=False, autoreload=False,
         env['session'] = session
 
     def setup_waltz():
-        web.config.debug = debug        
+        def fcgi(func, addr=None):
+            """nginx with spawn-fcgi"""
+            return web.wsgi.runfcgi(func, addr)
+        web.config.debug = debug
         if debug:
             PeriodicReloader()
+        if kwargs.get('fcgi'):
+            web.wsgi.runwsgi = fcgi
         db = kwargs.get('db', "%s/db" % _path)
+        lgr = kwargs.get('logging', '%s/events.log' % _path)
         def waltz_hook():
-            web.ctx.waltz = {"debug": debug, "db": db}
+            web.ctx.waltz = {"debug": debug,
+                             "db": db,
+                             "logging": lgr
+                             }
         app.add_processor(web.loadhook(waltz_hook))        
 
     setup_rendering()
@@ -95,13 +107,14 @@ def init_sessions(web, app, store, session):
     app.add_processor(web.loadhook(inject_session))
     return session
 
-def init_scaffolding(_path, **kwargs):
+def init_scaffolding(_path, appname="main.py", **kwargs):
     """Builds scaffolding for the project:
     static/, templates/, routes/, subapps/"""
 
     def build_static():
         """Builds a static/ directory within the project
         with subdirs: static/css, static/js, and static/imgs"""
+        from waltz.static import style
         path = _path + '/static'
         if not os.path.exists(path):
             os.makedirs(path)
@@ -109,10 +122,14 @@ def init_scaffolding(_path, **kwargs):
             subpath = '%s/%s' % (path, subdir)
             if not os.path.exists(subpath):
                 os.makedirs(subpath)
+        stylecss = path + "/css/style.css"
+        if not os.path.exists(stylecss):
+            with open(stylecss, 'w') as f:
+                f.write(style)
 
     def build_routes():
         """Creates directories + __init__ files for route logic"""
-        for d in ['routes', 'subapps']:
+        for d in ['routes', 'subapps', 'test']:
             path = '%s/%s' % (_path, d)
             if not os.path.exists(path):
                 os.makedirs(path)
@@ -130,11 +147,24 @@ def init_scaffolding(_path, **kwargs):
             if not os.path.exists(base): 
                 with open(base, 'w') as f:
                     f.write(content)
+    
+    def build_app(appname):
+        from waltz.static import mainpy, homepy
+        appname += ".py" if appname[-3:] != ".py" else ""
+        homepypath = '%s/routes/home.py' % _path
+        mainpypath = '%s/%s' % (_path, appname)
+        for fname, content in [(mainpypath, mainpy),
+                               (homepypath, homepy)]:
+            if not os.path.exists(fname): 
+                with open(fname, 'w') as f:
+                    f.write(content)            
 
     build_static()
     build_routes()
     build_templates()
+    build_app(appname)
 
 def _preprocess(urls):
     """Can be used to inject routes in the future"""
     return urls
+
